@@ -24,7 +24,8 @@ import (
 	"sync/atomic"
 	"time"
 
-	cloudevents "github.com/cloudevents/sdk-go/v1"
+	cloudevents "github.com/cloudevents/sdk-go"
+	"go.opencensus.io/trace"
 	"go.uber.org/zap"
 
 	eventingv1alpha1 "knative.dev/eventing/pkg/apis/eventing/v1alpha1"
@@ -33,12 +34,12 @@ import (
 	"knative.dev/eventing/pkg/kncloudevents"
 	"knative.dev/eventing/pkg/logging"
 	"knative.dev/eventing/pkg/reconciler/trigger/path"
+	"knative.dev/eventing/pkg/tracing"
 	"knative.dev/eventing/pkg/utils"
+	"knative.dev/pkg/network"
 )
 
 const (
-	writeTimeout = 15 * time.Minute
-
 	passFilter FilterResult = "pass"
 	failFilter FilterResult = "fail"
 	noFilter   FilterResult = "no_filter"
@@ -165,7 +166,7 @@ func (r *Handler) Start(ctx context.Context) error {
 	select {
 	case err := <-errCh:
 		return err
-	case <-time.After(writeTimeout):
+	case <-time.After(network.DefaultDrainTimeout):
 		return errors.New("timeout shutting down ceClient")
 	}
 }
@@ -184,6 +185,18 @@ func (r *Handler) serveHTTP(ctx context.Context, event cloudevents.Event, resp *
 		return errors.New("unable to parse path as a Trigger")
 	}
 
+	ctx, span := trace.StartSpan(ctx, tracing.TriggerMessagingDestination(triggerRef.NamespacedName))
+	defer span.End()
+
+	if span.IsRecordingEvents() {
+		span.AddAttributes(
+			tracing.MessagingSystemAttribute,
+			tracing.MessagingProtocolHTTP,
+			tracing.TriggerMessagingDestinationAttribute(triggerRef.NamespacedName),
+			tracing.MessagingMessageIDAttribute(event.ID()),
+		)
+	}
+
 	// Remove the TTL attribute that is used by the Broker.
 	ttl, err := broker.GetTTL(event.Context)
 	if err != nil {
