@@ -28,9 +28,9 @@ import (
 
 	"k8s.io/apimachinery/pkg/labels"
 
-	cloudevents "github.com/cloudevents/sdk-go/v1"
-	cepkg "github.com/cloudevents/sdk-go/v1/cloudevents"
-	cehttp "github.com/cloudevents/sdk-go/v1/cloudevents/transport/http"
+	cloudevents "github.com/cloudevents/sdk-go"
+	cepkg "github.com/cloudevents/sdk-go/pkg/cloudevents"
+	cehttp "github.com/cloudevents/sdk-go/pkg/cloudevents/transport/http"
 	"github.com/google/go-cmp/cmp"
 	"go.uber.org/zap"
 	"go.uber.org/zap/zaptest"
